@@ -1,4 +1,4 @@
-# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2016 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
@@ -177,8 +177,6 @@ sub new {
 	bless($self, $package);
 
 	my $epp = $self->createElementNS($EPP_URN, 'epp');
-	$epp->setNamespace($SCHEMA_URI, 'xsi', 0);
-	$epp->setAttributeNS($SCHEMA_URI, 'schemaLocation', "$EPP_URN epp-1.0.xsd");
 	$self->addChild($epp);
 
 	my $el = $self->createElement($type);
@@ -312,7 +310,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2011 CentralNic Ltd. This module is free software; you can
+This module is (c) 2016 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
